@@ -20,7 +20,6 @@
 __author__ = "Petter Reinholdtsen <pere@hungry.com>"
 
 import sys
-import apt
 import gc
 import gi
 import fnmatch
@@ -65,39 +64,22 @@ def modalias_match(alias, candidates):
     return False
 
 
-def pkgs_handling_apt_modaliases(modaliaslist):
-    cache = apt.Cache()
-    cache.open(None)
-    thepkgs = {}
-    for pkg in cache:
-        version = pkg.candidate
-        if version is None:
-            version = pkg.installed
-        if version is None:
-            continue
-        record = version.record
-        if not 'Modaliases' in record:
-            continue
-        modaliases = record['Modaliases']
-        for modalias in modaliaslist:
-            if modalias_match(modalias, modaliases):
-                thepkgs[pkg.name] = True
-
-    # Workaround for bug #745487 in python-apt, fix resource leak
-    cache = None
-    gc.collect()
-
-    return thepkgs.keys()
-
-
 def pkgs_handling_appstream_modaliases(modaliaslist):
     thepkgs = {}
-    gi.require_version('AppStream', '1.0')
-    from gi.repository import AppStream
-    db = AppStream.Database()
-    db.open()
-
-    cpts = db.get_all_components()
+    try:
+        gi.require_version('AppStream', '1.0')
+        from gi.repository import AppStream
+    except ValueError:
+        return []
+    try:
+        pool = AppStream.Pool()
+        pool.load()
+        cpts = pool.get_components()
+    except AttributeError:
+        # Handle old API too (before version 0.10)
+        db = AppStream.Database()
+        db.open()
+        cpts = db.get_all_components()
     ma_cpts = list()
     for cpt in cpts:
         provided = cpt.get_provided_for_kind(AppStream.ProvidedKind.MODALIAS)
@@ -136,13 +118,14 @@ def check_packages_file(pkghash, fileref, modaliaslist):
 
 def pkgs_handling_extra_modaliases(modaliaslist):
     """
-Look up package-hardware mappings from svn and local file
+Look up package-hardware mappings from git and local file
 """
     thepkgs = {}
-    url = "http://anonscm.debian.org/gitweb/?p=collab-maint/isenkram.git;a=blob_plain;f=modaliases;hb=HEAD"
+    url = "https://anonscm.debian.org/cgit/collab-maint/isenkram.git/plain/modaliases"
     try:
         f = urllib.urlopen(url)
-        check_packages_file(thepkgs, f, modaliaslist)
+        if f.getcode() == 200:
+            check_packages_file(thepkgs, f, modaliaslist)
     except IOError, e:
         if errno.ENOENT == e.errno:  # Most likely lack network connection
             pass
@@ -176,13 +159,9 @@ def main():
     for pkg in sorted(pkgs_handling_appstream_modaliases(hwaliases)):
         print "  %s" % pkg
 
-    print "Locating packages supporting this hardware (extra, svn/local):"
+    print "Locating packages supporting this hardware (extra, git/local):"
     for pkg in sorted(pkgs_handling_extra_modaliases(hwaliases)):
         print "  %s" % pkg
 
-    print "Locating packages supporting this hardware (APT control field):"
-    for pkg in sorted(pkgs_handling_apt_modaliases(hwaliases)):
-        print "  %s" % pkg
-
 if __name__ == '__main__':
     main()
